==> ZenTaoPMS.max2.0.rc1.php7.0.zip: zentaopms/module/review/view/edit.html.php <==
<?php include '../../common/view/header.html.php';?>
<?php include '../../common/view/kindeditor.html.php';?>
<div id="mainContent" class="main-content fade">
  <div class="center-block">
    <div class="main-header">
      <h2><?php echo $lang->review->edit;?></h2>
    </div>
    <form class="load-indicator main-form form-ajax" method='post' enctype='multipart/form-data' id='dataform'>
      <table class="table table-form">
        <tbody>
          <?php if($project->product == 'multiple'):?>
          <tr>
            <th><?php echo $lang->review->product;?></th>
            <td><?php echo html::select('product', $products, $review->product, "class='form-control chosen'");?></td>
          </tr>
          <?php endif;?>
          <?php if($project->product == 'single'):;?>
          <?php echo html::hidden('product', key($products));?>
          <?php endif;?>
          <tr>
            <th class='w-120px'><?php echo $lang->review->object;?></th>
            <td><?php echo html::select('object', $lang->review->objectList, $review->category, "class='form-control chosen'");?></td>
            <td></td>
          </tr>
          <tr>
            <th><?php echo $lang->review->title;?></th>
            <td><?php echo html::input('title', $review->title, "class='form-control'");?></td>
          </tr>
          <tr>
            <th><?php echo $lang->review->reviewedBy;?></th>
            <td><?php echo html::select('reviewedBy[]', $reviewers, $review->reviewedBy, "class='form-control chosen' multiple");?></td>
          </tr>
          <tr>
            <th><?php echo $lang->review->deadline;?></th>
            <td><?php echo html::input('deadline', $review->deadline, "class='form-date form-control'");?></td>
          </tr>
          <tr>
            <th><?php echo $lang->review->comment;?></th>
            <td colspan='2'><?php echo html::textarea('comment', '', "class='form-control'");?></td>
          </tr>
          <tr>
            <td colspan='3' class='form-actions text-center'><?php echo html::submitButton() . html::backButton();?></td>
          </tr>
        </tbody>
      </table>
    </form>
  </div>
</div>
<?php js::set('reviewedBy', $review->reviewedBy)?>
<?php js::set('projectID', $review->project)?>
<script>
$('#object').change(function()
{
    var type = $(this).val();
    var link = createLink('review', 'ajaxGetRole', "projectID=" + projectID + '&object=' + type + '&reviewedBy=' + reviewedBy);
    $.post(link, function(data)
    {
        $('#reviewedBy').replaceWith(data);
        $('#reviewedBy_chosen').remove();
        $('#reviewedBy').chosen();
    })
})

$('#object').change();
</script>
<?php include '../../common/view/footer.html.php';?>

==> ZenTaoPMS.max2.2.php5.3_5.6.zip: zentaopms/module/review/view/edit.html.php <==
<?php include '../../common/view/header.html.php';?>
<?php include '../../common/view/kindeditor.html.php';?>
<?php js::set('template', $review->template);?>
<div id="mainContent" class="main-content fade">
  <div class="center-block">
    <div class="main-header">
      <h2><?php echo $lang->review->edit;?></h2>
    </div>
    <form class="load-indicator main-form form-ajax" method='post' enctype='multipart/form-data' id='dataform'>
      <table class="table table-form">
        <tbody>
          <tr>
            <th><?php echo $lang->review->product;?></th>
            <td><?php echo html::select('product', $products, $review->product, "class='form-control chosen'");?></td>
          </tr>
          <tr>
            <th class='w-120px'><?php echo $lang->review->object;?></th>
            <td><?php echo html::select('object', $lang->baseline->objectList, $review->category, "class='form-control chosen'");?></td>
            <td></td>
          </tr>
          <tr <?php if($review->category == 'PP') echo "class='hide'";?>>
            <th><?php echo $lang->review->template;?></th>
            <td><?php echo html::select('template', '', '', "class='form-control chosen'");?></td>
          </tr>
          <tr>
            <th><?php echo $lang->review->title;?></th>
            <td><?php echo html::input('title', $review->title, "class='form-control'");?></td>
          </tr>
          <tr>
            <th><?php echo $lang->review->reviewedBy;?></th>
            <td><?php echo html::select('reviewedBy[]', $members, $review->reviewedBy, "class='form-control chosen' multiple");?></td>
          </tr>
          <tr>
            <th><?php echo $lang->review->deadline;?></th>
            <td><?php echo html::input('deadline', helper::isZeroDate($review->deadline) ? '' : $review->deadline, "class='form-date form-control'");?></td>
          </tr>
          <tr>
            <th><?php echo $lang->review->comment;?></th>
            <td colspan='2'><?php echo html::textarea('comment', '', "class='form-control'");?></td>
          </tr>
          <tr>
            <td colspan='3' class='form-actions text-center'><?php echo html::submitButton() . html::backButton();?></td>
          </tr>
        </tbody>
      </table>
    </form>
  </div>
</div>
<?php js::set('projectID', $review->project)?>
<script>
$('#object').change(function()
{
    var type = $(this).val();
    if(type == 'PP')
    {
        $('#template').closest('tr').addClass('hide');
    }
    else
    {
        $('#template').closest('tr').removeClass('hide');
    }

    var link = createLink('baseline', 'ajaxGetTemplates', 'type=' + type);
    $.post(link, function(data)
    {
        $('#template').replaceWith(data); 
        $('#template_chosen').remove();
        $('#template').val(template); 
        $('#template').chosen(); 
    })
})

$('#object').change();
</script>
<?php include '../../common/view/footer.html.php';?>
